@@ -11,7 +11,7 @@ data = d.read_data(chan=('EEG Fpz-Cz', 'EEG Pz-Oz'), begtime=35790, endtime=3582
 
 def test_detect_spindle_Moelle2011():
     detsp = DetectSpindle()
-    assert repr(detsp) == 'detsp_Moelle2011_11-18Hz_00.5-02.0s'
+    assert repr(detsp) == 'detsp_Moelle2011_09-15Hz_00.5-03.0s'
 
     sp = detsp(data)
     assert len(sp.events) == 3
@@ -40,10 +40,15 @@ def test_detect_spindle_Ferrarelli2007():
 
 def test_detect_spindle_UCSD():
     detsp = DetectSpindle(method='UCSD')
-    
-    sp = detsp(data)
-    assert len(sp.events) == 4
 
+    sp = detsp(data)
+    assert len(sp.events) == 6
+
+def test_detect_spindle_Concordia():
+    detsp = DetectSpindle(method='Concordia')
+
+    sp = detsp(data)
+    assert (len(sp.events)) == 4
 
 def test_detect_spindle_unknownmethod():
     with raises(ValueError):
@@ -51,7 +56,7 @@ def test_detect_spindle_unknownmethod():
 
 def test_merge_close():
     detsp = DetectSpindle(method='Nir2011')
-    
+
     sp = detsp(data)
     assert len(sp.events) == 2
 
@@ -63,8 +68,8 @@ def test_detect_spindle_to_data():
     assert sp_data(0)[0] == 1
 
     sp_freq = sp.to_data('peak_freq')
-    assert approx(sp_freq(0)[0]) == 14.5833333
-    
+    assert approx(sp_freq(0)[0]) == 13.114754098360656
+
     sp_ptp = sp.to_data('ptp')
-    assert approx(sp_ptp(0)[0]) == 66.3384615
+    assert approx(sp_ptp(0)[0]) == 63.53406593406595
 
