@@ -6,36 +6,33 @@ except ImportError:
     raise ImportError('You need to install PyQt5 to run GUI')
 
 
-from logging import getLogger, INFO, StreamHandler, Formatter
-
-lg = getLogger('wonambi')
-FORMAT = '%(asctime)s %(filename)s/%(funcName)s (%(levelname)s): %(message)s'
-DATE_FORMAT = '%H:%M:%S'
-
-formatter = Formatter(fmt=FORMAT, datefmt=DATE_FORMAT)
-handler = StreamHandler()
-handler.setFormatter(formatter)
-
-lg.handlers = []
-lg.addHandler(handler)
-
-lg.setLevel(INFO)
-
+from argparse import ArgumentParser
+from logging import getLogger, StreamHandler, Formatter, INFO, DEBUG
 from datetime import datetime
-now = datetime.now()
 from types import MethodType
 
 from PyQt5.QtCore import QSettings
 from PyQt5.QtWidgets import QMainWindow, QMessageBox
+from PyQt5.QtGui import QIcon
 
 from . import __version__
 from .widgets.creation import (create_menubar, create_toolbar,
                                create_actions, create_widgets)
 from .widgets.settings import DEFAULTS
-from .widgets.utils import keep_recent_datasets
+from .widgets.utils import keep_recent_datasets, ICON
+
+now = datetime.now()
+
+lg = getLogger('wonambi')
+
+
+DESCRIPTION = """
+    Package to analyze EEG, ECoG and other electrophysiology formats. It
+    allows for visualization of the results and for a GUI that can be used to
+    score sleep stages.
+    """
 
 settings = QSettings("wonambi", "wonambi")
-lg.info('Reading settings from {}'.format(settings.fileName()))
 
 
 class MainWindow(QMainWindow):
@@ -45,6 +42,9 @@ class MainWindow(QMainWindow):
     def __init__(self):
         super().__init__()
 
+        lg.info('WONAMBI v{}'.format(__version__))
+        lg.debug('Reading settings from {}'.format(settings.fileName()))
+
         self.info = None
         self.labels = None
         self.channels = None
@@ -167,14 +167,21 @@ class MainWindow(QMainWindow):
         self.merge_dialog.update_event_types()
         self.merge_dialog.show()
 
+    def show_export_dataset_dialog(self):
+        """Create the dataset export dialog."""
+        self.export_dataset_dialog.update()
+        self.export_dataset_dialog.show()
+
     def show_spindle_dialog(self):
         """Create the spindle detection dialog."""
         self.spindle_dialog.update_groups()
+        self.spindle_dialog.update_cycles()
         self.spindle_dialog.show()
 
     def show_slow_wave_dialog(self):
         """Create the SW detection dialog."""
         self.slow_wave_dialog.update_groups()
+        self.slow_wave_dialog.update_cycles()
         self.slow_wave_dialog.show()
 
     def show_event_analysis_dialog(self):
@@ -186,10 +193,14 @@ class MainWindow(QMainWindow):
 
     def show_analysis_dialog(self):
         """Create the analysis dialog."""
-        self.analysis_dialog.update_types()
+        self.analysis_dialog.update_evt_types()
         self.analysis_dialog.update_groups()
         self.analysis_dialog.update_cycles()
         self.analysis_dialog.show()
+        
+    def show_plot_dialog(self):
+        """Create the plot frame widget."""
+        self.plot_dialog.show()
 
     def show_spindle_help(self):
         self.spindle_help.show()
@@ -248,10 +259,61 @@ app = None
 
 
 def main():
+
     global app
     app = QApplication([])
+    app.setWindowIcon(QIcon(ICON['application']))
 
-    q = MainWindow()
-    q.show()
+    parser = ArgumentParser(prog='wonambi',
+                            description=DESCRIPTION)
+    parser.add_argument('-v', '--version', action='store_true',
+                        help='Return version')
+    parser.add_argument('-l', '--log', default='info',
+                        help='Logging level: info (default), debug')
+    parser.add_argument('--reset', action='store_true',
+                        help='Reset (clear) configuration file')
+    parser.add_argument('dataset', nargs='?',
+                        help='full path to dataset to open')
+    parser.add_argument('annot', nargs='?',
+                        help='full path to annotations file to open')
+    parser.add_argument('montage', nargs='?',
+                        help='full path to montage file to open')
 
-    app.exec_()
+    args = parser.parse_args()
+
+    DATE_FORMAT = '%H:%M:%S'
+    if args.log[:1].lower() == 'i':
+        lg.setLevel(INFO)
+        FORMAT = '{asctime:<10}{message}'
+
+    elif args.log[:1].lower() == 'd':
+        lg.setLevel(DEBUG)
+        FORMAT = '{asctime:<10}{levelname:<10}{filename:<40}(l. {lineno: 6d})/ {funcName:<40}: {message}'
+
+    formatter = Formatter(fmt=FORMAT, datefmt=DATE_FORMAT, style='{')
+    handler = StreamHandler()
+    handler.setFormatter(formatter)
+
+    lg.handlers = []
+    lg.addHandler(handler)
+
+    if args.reset:
+        settings.clear()
+
+    if args.version:
+        lg.info('WONAMBI v{}'.format(__version__))
+
+    else:
+        q = MainWindow()
+        q.show()
+
+        if args.dataset:
+            q.info.open_dataset(args.dataset)
+            
+        if args.annot:
+            q.notes.update_notes(args.annot)
+            
+        if args.montage:
+            q.channels.load_channels(test_name=args.montage)
+
+        app.exec()
