@@ -13,13 +13,14 @@ from PyQt5.QtWidgets import (QAction,
 
 from .settings import (Settings, SlowWaveHelp, SpindleHelp,
                        EvtAnalysisHelp)  # has to be first
-from .utils import ICON  # has to be second
+from .utils import ICON   # has to be second
 from .labels import Labels
 from .channels import Channels
 from .info import Info, ExportDatasetDialog
 from .overview import Overview
-from .notes import (Notes, MergeDialog, SpindleDialog, SWDialog,
-                    EventAnalysisDialog)
+from .notes import Notes, MergeDialog
+from .detect_dialogs import SpindleDialog, SWDialog
+from .modal_widgets import EventAnalysisDialog
 from .analysis import AnalysisDialog, PlotDialog
 from .spectrum import Spectrum
 from .traces import Traces
@@ -218,6 +219,9 @@ def create_menubar(MAIN):
 
     menu_view.addAction(actions['cross_chan_mrk'])
 
+    menu_view.addSeparator()
+    menu_view.addAction(actions['export_svg'])
+
     """ ------ ANNOTATIONS ------ """
     actions = MAIN.notes.action
 
